@@ -1,30 +1,37 @@
 """Job that reads open ephys data, compresses, and writes it."""
+import json
 import logging
 import os
+import platform
 import subprocess
 import sys
-import platform
+import warnings
 from datetime import datetime, timezone
 from pathlib import Path
-import warnings
-import json
 
-from aind_data_transfer.codeocean import CodeOceanClient
+from aind_codeocean_api.codeocean import CodeOceanClient
+
 from aind_data_transfer.configuration_loader import EphysJobConfigurationLoader
 from aind_data_transfer.readers import EphysReaders
 from aind_data_transfer.transformations.compressors import EphysCompressors
-from aind_data_transfer.transformations.metadata_creation import ProcessingMetadata
-from aind_data_transfer.util.npopto_correction import correct_np_opto_electrode_locations
+from aind_data_transfer.transformations.metadata_creation import (
+    ProcessingMetadata,
+)
+from aind_data_transfer.util.npopto_correction import (
+    correct_np_opto_electrode_locations,
+)
 from aind_data_transfer.writers import EphysWriters
 
 root_logger = logging.getLogger()
 
 # Suppress a warning from one of the third-party libraries
-deprecation_msg = ("Creating a LegacyVersion has been deprecated and will be "
-                   "removed in the next major release")
-warnings.filterwarnings("ignore",
-                        category=DeprecationWarning,
-                        message=deprecation_msg)
+deprecation_msg = (
+    "Creating a LegacyVersion has been deprecated and will be "
+    "removed in the next major release"
+)
+warnings.filterwarnings(
+    "ignore", category=DeprecationWarning, message=deprecation_msg
+)
 
 # TODO: Break these up into importable jobs to fix the flake8 warning?
 if __name__ == "__main__":  # noqa: C901
@@ -149,11 +156,13 @@ if __name__ == "__main__":  # noqa: C901
                     dest_data_dir,
                     aws_dest,
                     "--dryrun",
-                ], shell=shell
+                ],
+                shell=shell,
             )
         else:
-            subprocess.run(["aws", "s3", "sync", dest_data_dir, aws_dest],
-                           shell=shell)
+            subprocess.run(
+                ["aws", "s3", "sync", dest_data_dir, aws_dest], shell=shell
+            )
         logging.info("Finished uploading to s3.")
 
     # Upload to gcp
@@ -172,12 +181,13 @@ if __name__ == "__main__":  # noqa: C901
                     "-n",
                     dest_data_dir,
                     gcp_dest,
-                ], shell=shell
+                ],
+                shell=shell,
             )
         else:
             subprocess.run(
                 ["gsutil", "-m", "rsync", "-r", dest_data_dir, gcp_dest],
-                shell=shell
+                shell=shell,
             )
         logging.info("Finished uploading to gcp.")
 
@@ -186,11 +196,10 @@ if __name__ == "__main__":  # noqa: C901
         capsule_id = job_configs["trigger_codeocean_job"]["capsule_id"]
         co_api_token = os.getenv("CODEOCEAN_API_TOKEN")
         co_domain = job_configs["endpoints"]["codeocean_domain"]
-        co_client = CodeOceanClient(domain=co_domain,
-                                    token=co_api_token)
+        co_client = CodeOceanClient(domain=co_domain, token=co_api_token)
         run_response = co_client.run_capsule(
             capsule_id=capsule_id,
             data_assets=[],
-            parameters=[json.dumps(job_configs)]
+            parameters=[json.dumps(job_configs)],
         )
         logging.debug(f"Run response: {run_response.json()}")
